
/*
 *  comm.c
 *  Copyright (C) 1999 Brad Proctor
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * $Id: comm.c,v 1.4 1999/06/21 15:04:55 brad Exp $
 */

#include <stdio.h>
#include "version.h"

static char help_text[] =
{
   "Usage: comm [-123] file1 file2\n\n"
   "  -1         Suppress lines unique to file1\n"
   "  -2         Suppress lines unique to file2\n"
   "  -3         Suppress lines duplicated in file1 and file2\n"
   "  --help     Print this help message\n"
   "  --version  Print the program version\n\n"
   "Report bugs to fredlie@sprynet.com"
};

static char flag_1 = 0;
static char flag_2 = 0;
static char flag_3 = 0;
static FILE *file1 = 0;
static FILE *file2 = 0;

/*
 * Main
 */

int main(int argc, char **argv)
{
   int i;
   char *ptr;
   
   for(i = 1; i < argc; ++i)
   {
      ptr = argv[i];
      if(*ptr == '-')
      {
         while(*++ptr)
         switch(*ptr)
         {
            case '-':
               ++ptr;
               if(!strcmp(ptr, "help"))
               {
                  puts(help_text);
                  return (0);
               }
               else if(!strcmp(ptr, "version"))
               {
                  puts("comm (butils) "VERSION_STRING);
                  return (0);
               }
               else if(*ptr == '\0')
               {
                  if(!file1)
                     file1 = stdin;
                  else if(!file2)
                     file2 = stdin;
               }
               break;
            case '1': flag_1 = 1; break;
            case '2': flag_2 = 1; break;
            case '3': flag_3 = 1; break;
            default:
         }
      }
      else if(!file1)
      {
         if((file1 = fopen(argv[i], "r")) == NULL)
         {
            fprintf(stderr, "%s: Could not open `%s' for reading.\n", 
               argv[0], argv[i]);
            fputs("Try `%s --help' for more information.\n", stderr);
            return (1);
         }
      }
      else if(!file2)
      {
         if((file1 = fopen(argv[i], "r")) == NULL)
         {
            fprintf(stderr, "%s: Could not open `%s' for reading.\n", 
               argv[0], argv[i]);
            fputs("Try `%s --help' for more information.\n", stderr);
            return (1);
         }
      }
   }
   return (0);
}